@@ -21,9 +21,13 @@
  * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GLib Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GLib at ftp://ftp.gtk.org/pub/gtk/. 
+ * GLib at ftp://ftp.gtk.org/pub/gtk/.
  */
 
+#if defined(G_DISABLE_SINGLE_INCLUDES) && !defined (__GLIB_H_INSIDE__) && !defined (GLIB_COMPILATION)
+#error "Only <glib.h> can be included directly."
+#endif
+
 #ifndef __G_COMPLETION_H__
 #define __G_COMPLETION_H__
 
@@ -52,6 +56,8 @@ struct _GCompletion
   GCompletionStrncmpFunc strncmp_func;
 };
 
+#ifndef G_DISABLE_DEPRECATED
+
 GCompletion* g_completion_new           (GCompletionFunc func);
 void         g_completion_add_items     (GCompletion*    cmp,
                                          GList*          items);
@@ -68,7 +74,8 @@ void         g_completion_set_compare   (GCompletion *cmp,
 				         GCompletionStrncmpFunc strncmp_func);
 void         g_completion_free          (GCompletion*    cmp);
 
+#endif
+
 G_END_DECLS
 
 #endif /* __G_COMPLETION_H__ */
-
